==> oddmuse-1.310.tar.gz: oddmuse-1.310/serbian-utf8.pl <==
# UTF-8 encoded Serbian translation file for use with Oddmuse
#
# Copyright (c) 2003  Unknown
# Copyright (c) 2003  Chusslove Illich
#
# Permission is granted to copy, distribute and/or modify this document
# under the terms of the GNU Free Documentation License, Version 1.2
# or any later version published by the Free Software Foundation;
# with no Invariant Sections, no Front-Cover Texts, and no Back-Cover Texts.
# A copy of the license could be found at: http://www.gnu.org/licenses/fdl.txt .
#
# Installation:
# =============
# This file should be saved into the same folder where the config file
# resides.  Load it from the config file:
#
# do 'serbian-utf8.pl';
#
# This translation was last checked for Oddmuse version 1.195.
#
%Translate = split('\n',<<END_OF_TRANSLATION);
Reading not allowed: user, ip, or network is blocked.
Читање није дозвољено: приступ за корисника, IP број или мрежу је блокиран.
Could not create %s
Не могу да направим %s
Invalid UserName %s: not saved.
Неисправно корисничко име %s: није снимљено.
UserName must be 50 characters or less: not saved
Корисничко име мора имати 50 или мање знакова: није снимљено.
XML::RSS is not available on this system.

LWP::UserAgent is not available on this system.

diff

history
историјат
 . . . . 

Click to create this page

http://shop.barnesandnoble.com/bookSearch/isbnInquiry.asp?isbn=%s

http://www.amazon.com/exec/obidos/ISBN=%s

alternate
други
http://www.pricescan.com/books/BookDetail.asp?isbn=%s

search
претрага
Invalid action parameter %s
Неисправан параметар акције %s
Invalid URL.
Неисправан URL.
Page name is too long: %s
Име странице је предугачко: %s
Invalid Page %s
Неисправна страница %s
Invalid Page %s (must not end with .db)
Неисправна страница %s (не сме имати наставак .db)
Invalid Page %s (must not end with .lck)
Неисправна страница %s (не сме имати наставак .lck)
Page name may not contain space characters: %s
Име странице не може садржати размаке: %s
Preview:
Преглед:
Preview only, not yet saved
Ово је само преглед, измена још увек није записана
Please go on to %s.
Настави до %s.
Could not open %s log file
Нисам могао да отворим дневничку датотеку %s
Error was
Грешка
Note: This error is normal if no changes have been made.
Пажња: Ова грешка је уобичајена уколико ништа нисте изменили.
Could not open old %s log file
Нисам могао да отворим стару дневничку датотеку %s
No updates since %s
Нема измена од %s
Updates since %s
Измене од %s
Updates in the last %s days
Измене у последњих %s дана
Updates in the last %s day
Измене у последњи %s дан
for %s only
само за %s
List latest change per page only

List only major changes

Include minor changes

List all changes

%s days
%s дана
List later changes

Username:
Корисничко име:
Host:

Language:

Filters

Go!
Иди!
(minor)
(ситна)
rollback
повратак
from %s
од %s
History of %s
Историјат за %s
Compare
Упореди
Revision %s
Верзија %s
by
—
Rolling back changes
Враћам измене
Missing target for rollback.
Недостаје циљ за повратак.
Target for rollback is too far back.
Циљ за повратак је предалеко уназад.
Rollback to %s
Повратак на %s
%s rolled back
%s је враћен
[Home]
[Кућа]
redirected from %s
преусмерено са %s
Click to search for references to this page

Cookie: 
Колачић: 
new comment
нови коментар
Save
Сачувај
Preview
Преглед
Comments on this page
Коментари на овој страни
Edit revision %s of this page
Уреди верзију %s ове странице
Edit text of this page
Уреди текст ове странице
This page is read-only
Ова страница је само за читање
View other revisions
Прикажи остале верзије
View current revision
Прикажи тренутну верзију
View all changes
Прикажи све измене
Back to %s

Last edited
Последње уређивање
Edited
Уређено
by %s
— %s
(diff)
(разлике)
Warning
Упозорење
Database is stored in temporary directory %s
База је снимљена у привремени директоријум %s
%s seconds
%s секунди
The same page on other sites:

EditNearLinks

Search:
Пронађи:
Replace:
Замени:
Validate HTML
Провери HTML
Validate CSS
Провери CSS
Difference (from revision %1 to %2)

revision %s
верзија %s
current revision
текућа верзија
Difference (from prior %s revision)
Разлика (текућа верзија у односу на претходну - %s)
major
крупна
minor
ситна
No diff available.
Разлика није доступна.
Changed:
Измењено:
Removed:
Уклоњено:
Added:
Додато:
to
у
Revision %s not available
Верзија %s није доступна
showing current revision instead
уместо тога, користи се тренутна верзија
Showing revision %s
Приказана верзија %s
Cannot save an nameless page.
Не могу да снимим безимену страну.
Cannot open %s

Cannot write %s

Could not get %s lock
Нисам могао да добавим браву %s
Unlocking
Откључавам
This operation may take several seconds...
Ова операција може потрајати неколико секунди...
Forced unlock of %s lock.
Форсирано откључавање браве %s.
No unlock required.
Откључавање није неопходно.
%s hours ago
пре %s часова
1 hour ago
пре 1 часа
%s minutes ago
пре %s минута
1 minute ago
пре 1 минута
%s seconds ago
пре %s секунди
1 second ago
пре 1 секунде
just now
управо сада
Editing Denied
Уређивање је одбијено
Editing not allowed: user, ip, or network is blocked.
Уређивање није дозвољено: приступ за корисника, IP број или мрежу је блокиран.
Contact the wiki administrator for more information.
Обратите се администратору за више информација.
The rule %s matched for you.

See %s for more information.
Погледајте %s за више информација.
Editing not allowed: %s is read-only.
Уређивање није дозвољено: %s је само за читање.
Only administrators can upload files.
Само администратори могу да каче датотеке.
Editing revision %s of
Уређује се верзија %s
Editing %s
Уређивање %s
Editing old revision %s.
Уређивање старе верзије %s.
Saving this page will replace the latest revision with this text.
Снимање ове странице ће преписати последњу верзију новим текстом.
Summary:
Сажетак:
This change is a minor edit.
Ово је ситна измена.
Replace this file with text.
Замени ову датотеку текстом.
Replace this text with a file.
Замени овај текст датотеком.
File to upload: 
Датотека коју треба окачити: 
Files of type %s are not allowed.
Датотеке типа %s нису дозвољене.
Password
Лозинка
Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
Ваша лозинка је снимљена у колачићу, ако су укључени. Колачићи могу бити изгубљени ако се повежете са друге машине, са другог налога, или користећи други програм.
You are currently an administrator on this site.
Тренутно сте администратор на овом сајту.
You are currently an editor on this site.
Тренутно сте уредник на овом сајту.
You are a normal user on this site.
Ви сте нормални корисник на овом сајту.
Your password does not match any of the  administrator or editor passwords.
Ваша лозинка се не поклапа ни са једном од аминистраторских или уредничких лозинки.
Password:
Лозинка:
This site does not use admin or editor passwords.
Овај сајт не користи администраторске или уредничке лозинке.
This operation is restricted to site editors only...
Ово смеју да раде само уредници сајта...
This operation is restricted to administrators only...
Ово сме да ради само администратор...
Index of all pages
Списак свих страна:
all pages

permanent anchors

near links

(for %s)

%s pages found.

Replaced: %s
Замењено: %s
Search for: %s
Тражи: %s
View changes for these pages

Search sites on the %s as well

and

or

Fetching results from %s:

Near pages:

last updated
последњи пут ажурирана
Full Link List
Потпуни списак веза
Complete Content
Потпуни садржај
The main page is %s.
Главна страна је %s.
Editing not allowed for %s.
Уређивање није дозвољено за %s.
SampleUndefinedPage
НенаписанаСтраницаЗаПример
%s cannot be defined.
%s се не може дефинисати.
Sample_Undefined_Page
Ненаписана_Страница_За_Пример
[[%s]] cannot be defined.
[[%s]] се не може дефинисати.
Only an administrator can create %s
Само администратор може да направи %s
Transfer Error: %s
Грешка у преносу: %s
Browser reports no file info.
Прегледач не пријављује информације о датотеци.
Browser reports no file type.
Прегледач не пријављује тип датотеке.
This page was changed by somebody else %s.
Ову страницу је изменио неко други %s.
The changes conflict.  Please check the page again.
Измене су у сукобу. Проверите страну поново.
Please check whether you overwrote those changes.
Проверите да нисте пребрисали ове те измене.
Anonymous
Анонимони
Could not get a lock to merge!
Нисам могао да добавим браву за стапање!
you
ви
ancestor
предак
other
други
Ping
Пинг
No response.
Нема одзива
Maintenance on all pages
Одржавање на свим странама
Maintenance not done.
Одржавање није урађено.
(Maintenance can only be done once every 12 hours.)
(Одржавање може да се уради једном сваких 13 часова.)
Remove the "maintain" file or wait.
Уклони датотеку одржавања или чекај.
Main lock obtained.
Главна брава је добављена.
Expiring keep files and deleting pages marked for deletion
Истичем датотеке чувања и бришем странице означене за брисање
deleted
обрисано
Moving part of the %s log file.
Премештам део дневничке датотеке %s.
Moving %s log entries.
Премештам %s дневничких ставки.
Getting page index file for %s.

Main lock released.
Главна брава је отпуштена.
Set or Remove global edit lock
Постави или уклони глобалну браву за уређивање
Edit lock created.
Брава за уређивање је направљена.
Edit lock removed.
Брава за уређивање је уклоњена.
Set or Remove page edit lock
Постави или уклони браву за уређивање стране
Missing page id to lock/unlock...
Недостаје ид. стране коју треба откључати/закључати
Lock for %s created.
Брава за %s је направљена.
Lock for %s removed.
Брава за %s је уклоњена.
Displaying Wiki Version
Приказујем верзију Викија
Inter links:

Near links:

Too many connections by %s
Превише веза од %s
Recent Visitors
Скори посетиоци
Referrers
Референце
All Referrers
Све референце
anchor first defined here: %s
сидро је прво дефинисано овде: %s
Click to search for references to this permanent anchor

END_OF_TRANSLATION

==> oddmuse-1.437.tar.gz: oddmuse-1.437/serbian-utf8.pl <==
# UTF-8 encoded Serbian translation file for use with Oddmuse
#
# Copyright (c) 2003  Unknown
# Copyright (c) 2003  Chusslove Illich
#
# Permission is granted to copy, distribute and/or modify this document
# under the terms of the GNU Free Documentation License, Version 1.2
# or any later version published by the Free Software Foundation;
# with no Invariant Sections, no Front-Cover Texts, and no Back-Cover Texts.
# A copy of the license could be found at: http://www.gnu.org/licenses/fdl.txt .
#
# Installation:
# =============
#
# Create a modules subdirectory in your data directory, and put the
# file in there. It will be loaded automatically.
#
# This translation was last checked for Oddmuse version 1.195.
#
%Translate = split('\n',<<END_OF_TRANSLATION);
Reading not allowed: user, ip, or network is blocked.
Читање није дозвољено: приступ за корисника, IP број или мрежу је блокиран.
Could not create %s
Не могу да направим %s
Invalid UserName %s: not saved.
Неисправно корисничко име %s: није снимљено.
UserName must be 50 characters or less: not saved
Корисничко име мора имати 50 или мање знакова: није снимљено.
XML::RSS is not available on this system.

diff

history
историјат
%s returned no data, or LWP::UserAgent is not available.

RSS parsing failed for %s

 . . . . 

Click to create this page

http://shop.barnesandnoble.com/bookSearch/isbnInquiry.asp?isbn=%s

http://www.amazon.com/exec/obidos/ISBN=%s

alternate
други
http://www.pricescan.com/books/BookDetail.asp?isbn=%s

search
претрага
Invalid action parameter %s
Неисправан параметар акције %s
Invalid URL.
Неисправан URL.
Page name is missing

Page name is too long: %s
Име странице је предугачко: %s
Invalid Page %s
Неисправна страница %s
Invalid Page %s (must not end with .db)
Неисправна страница %s (не сме имати наставак .db)
Invalid Page %s (must not end with .lck)
Неисправна страница %s (не сме имати наставак .lck)
Page name may not contain space characters: %s
Име странице не може садржати размаке: %s
Preview:
Преглед:
Preview only, not yet saved
Ово је само преглед, измена још увек није записана
Please go on to %s.
Настави до %s.
Could not open %s log file
Нисам могао да отворим дневничку датотеку %s
Error was
Грешка
Note: This error is normal if no changes have been made.
Пажња: Ова грешка је уобичајена уколико ништа нисте изменили.
Could not open old %s log file
Нисам могао да отворим стару дневничку датотеку %s
No updates since %s
Нема измена од %s
Updates since %s
Измене од %s
Updates in the last %s days
Измене у последњих %s дана
Updates in the last %s day
Измене у последњи %s дан
for %s only
само за %s
List latest change per page only

List all changes

List only major changes

Include minor changes

%s days
%s дана
List later changes

Username:
Корисничко име:
Host:

Language:

Filters

Go!
Иди!
(minor)
(ситна)
rollback
повратак
new

from %s
од %s
History of %s
Историјат за %s
Compare
Упореди
Revision %s
Верзија %s
by
—
Rolling back changes
Враћам измене
Missing target for rollback.
Недостаје циљ за повратак.
Target for rollback is too far back.
Циљ за повратак је предалеко уназад.
Rollback to %s
Повратак на %s
%s rolled back
%s је враћен
[Home]
[Кућа]
redirected from %s
преусмерено са %s
Click to search for references to this page

Cookie: 
Колачић: 
Warning
Упозорење
Database is stored in temporary directory %s
База је снимљена у привремени директоријум %s
%s seconds
%s секунди
The same page on other sites:

EditNearLinks

Last edited
Последње уређивање
Edited
Уређено
by %s
— %s
(diff)
(разлике)
Run maintenance

Unlock site

Lock site

Unlock page

Lock page

Comments on this page
Коментари на овој страни
Edit revision %s of this page
Уреди верзију %s ове странице
Edit text of this page
Уреди текст ове странице
e

This page is read-only
Ова страница је само за читање
View other revisions
Прикажи остале верзије
View current revision
Прикажи тренутну верзију
View all changes
Прикажи све измене
Back to %s

new comment
нови коментар
s

Save
Сачувај
Preview
Преглед
Search:
Пронађи:
Replace:
Замени:
Validate HTML
Провери HTML
Validate CSS
Провери CSS
Difference (from revision %1 to %2)

revision %s
верзија %s
current revision
текућа верзија
Difference (from prior %s revision)
Разлика (текућа верзија у односу на претходну - %s)
major
крупна
minor
ситна
No diff available.
Разлика није доступна.
Changed:
Измењено:
Removed:
Уклоњено:
Added:
Додато:
to
у
Revision %s not available
Верзија %s није доступна
showing current revision instead
уместо тога, користи се тренутна верзија
Showing revision %s
Приказана верзија %s
Cannot save an nameless page.
Не могу да снимим безимену страну.
Cannot open %s

Cannot write %s

Could not get %s lock
Нисам могао да добавим браву %s
Unlocking
Откључавам
This operation may take several seconds...
Ова операција може потрајати неколико секунди...
Forced unlock of %s lock.
Форсирано откључавање браве %s.
No unlock required.
Откључавање није неопходно.
%s hours ago
пре %s часова
1 hour ago
пре 1 часа
%s minutes ago
пре %s минута
1 minute ago
пре 1 минута
%s seconds ago
пре %s секунди
1 second ago
пре 1 секунде
just now
управо сада
Editing Denied
Уређивање је одбијено
Editing not allowed: user, ip, or network is blocked.
Уређивање није дозвољено: приступ за корисника, IP број или мрежу је блокиран.
Contact the wiki administrator for more information.
Обратите се администратору за више информација.
The rule %s matched for you.

See %s for more information.
Погледајте %s за више информација.
Editing not allowed: %s is read-only.
Уређивање није дозвољено: %s је само за читање.
Only administrators can upload files.
Само администратори могу да каче датотеке.
Editing revision %s of
Уређује се верзија %s
Editing %s
Уређивање %s
Editing old revision %s.
Уређивање старе верзије %s.
Saving this page will replace the latest revision with this text.
Снимање ове странице ће преписати последњу верзију новим текстом.
Summary:
Сажетак:
This change is a minor edit.
Ово је ситна измена.
Replace this file with text.
Замени ову датотеку текстом.
Replace this text with a file.
Замени овај текст датотеком.
File to upload: 
Датотека коју треба окачити: 
Files of type %s are not allowed.
Датотеке типа %s нису дозвољене.
Password
Лозинка
Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
Ваша лозинка је снимљена у колачићу, ако су укључени. Колачићи могу бити изгубљени ако се повежете са друге машине, са другог налога, или користећи други програм.
You are currently an administrator on this site.
Тренутно сте администратор на овом сајту.
You are currently an editor on this site.
Тренутно сте уредник на овом сајту.
You are a normal user on this site.
Ви сте нормални корисник на овом сајту.
Your password does not match any of the  administrator or editor passwords.
Ваша лозинка се не поклапа ни са једном од аминистраторских или уредничких лозинки.
Password:
Лозинка:
This site does not use admin or editor passwords.
Овај сајт не користи администраторске или уредничке лозинке.
This operation is restricted to site editors only...
Ово смеју да раде само уредници сајта...
This operation is restricted to administrators only...
Ово сме да ради само администратор...
Index of all pages
Списак свих страна:
all pages

permanent anchors

near links

(for %s)

%s pages found.

Replaced: %s
Замењено: %s
Search for: %s
Тражи: %s
View changes for these pages

Search sites on the %s as well

and

or

Fetching results from %s:

Near pages:

last updated
последњи пут ажурирана
Complete Content
Потпуни садржај
The main page is %s.
Главна страна је %s.
Editing not allowed for %s.
Уређивање није дозвољено за %s.
SampleUndefinedPage
НенаписанаСтраницаЗаПример
%s cannot be defined.
%s се не може дефинисати.
Sample_Undefined_Page
Ненаписана_Страница_За_Пример
[[%s]] cannot be defined.
[[%s]] се не може дефинисати.
Only an administrator can create %s.

Transfer Error: %s
Грешка у преносу: %s
Browser reports no file info.
Прегледач не пријављује информације о датотеци.
Browser reports no file type.
Прегледач не пријављује тип датотеке.
Edit Denied

The page contains banned text.

This page was changed by somebody else %s.
Ову страницу је изменио неко други %s.
The changes conflict.  Please check the page again.
Измене су у сукобу. Проверите страну поново.
Please check whether you overwrote those changes.
Проверите да нисте пребрисали ове те измене.
Anonymous
Анонимони
Could not get a lock to merge!
Нисам могао да добавим браву за стапање!
you
ви
ancestor
предак
other
други
Maintenance on all pages
Одржавање на свим странама
Maintenance not done.
Одржавање није урађено.
(Maintenance can only be done once every 12 hours.)
(Одржавање може да се уради једном сваких 13 часова.)
Remove the "maintain" file or wait.
Уклони датотеку одржавања или чекај.
Main lock obtained.
Главна брава је добављена.
Expiring keep files and deleting pages marked for deletion
Истичем датотеке чувања и бришем странице означене за брисање
not deleted: 

deleted
обрисано
Moving part of the %s log file.
Премештам део дневничке датотеке %s.
Moving %s log entries.
Премештам %s дневничких ставки.
Getting page index file for %s.

Main lock released.
Главна брава је отпуштена.
Set or Remove global edit lock
Постави или уклони глобалну браву за уређивање
Edit lock created.
Брава за уређивање је направљена.
Edit lock removed.
Брава за уређивање је уклоњена.
Set or Remove page edit lock
Постави или уклони браву за уређивање стране
Missing page id to lock/unlock...
Недостаје ид. стране коју треба откључати/закључати
Lock for %s created.
Брава за %s је направљена.
Lock for %s removed.
Брава за %s је уклоњена.
Displaying Wiki Version
Приказујем верзију Викија
Inter links:

Near links:

Too many connections by %s
Превише веза од %s
Please do not fetch more than %1 pages in %2 seconds.

Recent Visitors
Скори посетиоци
Referrers
Референце
All Referrers
Све референце
anchor first defined here: %s
сидро је прво дефинисано овде: %s
Click to search for references to this permanent anchor

the page %s also exists

Deleting %s

Deleted %s

Renaming %1 to %2.

The page %s does not exist

The page %s already exists

Renamed to %s

Renamed from %s

Renamed %1 to %2.

Delete page

Rename this page to:

Missing one of cal(1), Date::Calc(3), or Date::Pcalc(3) to produce the calendar.

The match parameter is missing.

Page Collection for %s

Calendar %s

Footnotes:

image: %s

Languages:

Show!

Define

Full Link List
Потпуни списак веза
Clearing Cache

Done.

Generating Link Database

The 404 handler extension requires the link data extension (links.pl).

Orphan List

Trail: 

None

Type

Portrait

Thread: %s

ID parameter is missing.

Thread %s does not exist.

Page %s does not contain a thread.

Add

URL parameter is missing.

Add to %s thread

Below:

URL:

Name:

Blog

END_OF_TRANSLATION
